# <div align="center"> video-specs

Fill a form about the specifications of the video you want to generate and get the whole video description formatted either in XML, in JSON, HTML or in Markdown text blocks.

## Pre requisites

- Python 3.11+
- `uv` is definitely recommended

## Quick Start

### With `homebrew`:

```bash
brew tap dim-gggl/brew
brew install video-specs
```

### With `uv`

1. Global installation

```bash
uv tool install video-specs
```

2. Local installation (venv)

```bash
uv add video-specs
```

### with `pip`

```bash
pip install video-specs
```

## Start

```bash
video-specs
```

This should launch the interactive mode, otherwise you can start with a simple :

```bash
video-specs --help
```